
# Class: entity


Root Biolink Model class for all things and informational relationships, real or imagined.

URI: [biolink:Entity](https://w3id.org/biolink/vocab/Entity)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[NamedThing],[Attribute]<has%20attribute%200..*-++[Entity&#124;id:string;iri:iri_type%20%3F;category:category_type%20*;type:string%20%3F;name:label_type%20%3F;description:narrative_text%20%3F;source:label_type%20%3F],[Agent]<provided%20by%200..*-%20[Entity],[Entity]^-[NamedThing],[Entity]^-[Association],[Attribute],[Association],[Agent])](https://yuml.me/diagram/nofunky;dir:TB/class/[NamedThing],[Attribute]<has%20attribute%200..*-++[Entity&#124;id:string;iri:iri_type%20%3F;category:category_type%20*;type:string%20%3F;name:label_type%20%3F;description:narrative_text%20%3F;source:label_type%20%3F],[Agent]<provided%20by%200..*-%20[Entity],[Entity]^-[NamedThing],[Entity]^-[Association],[Attribute],[Association],[Agent])

## Children

 * [Association](Association.md) - A typed association between two entities, supported by evidence
 * [NamedThing](NamedThing.md) - a databased entity or concept/class

## Referenced by Class


## Attributes


### Own

 * [id](id.md)  <sub>1..1</sub>
     * Description: A unique identifier for an entity. Must be either a CURIE shorthand for a URI or a complete URI
     * Range: [String](types/String.md)
     * in subsets: (translator_minimal)
 * [iri](iri.md)  <sub>0..1</sub>
     * Description: An IRI for an entity. This is determined by the id using expansion rules.
     * Range: [IriType](types/IriType.md)
     * in subsets: (translator_minimal,samples)
 * [category](category.md)  <sub>0..\*</sub>
     * Description: Name of the high level ontology class in which this entity is categorized. Corresponds to the label for the biolink entity type class.
 * In a neo4j database this MAY correspond to the neo4j label tag.
 * In an RDF database it should be a biolink model class URI.
This field is multi-valued. It should include values for ancestors of the biolink class; for example, a protein such as Shh would have category values `biolink:Protein`, `biolink:GeneProduct`, `biolink:MolecularEntity`, ...
In an RDF database, nodes will typically have an rdf:type triples. This can be to the most specific biolink class, or potentially to a class more specific than something in biolink. For example, a sequence feature `f` may have a rdf:type assertion to a SO class such as TF_binding_site, which is more specific than anything in biolink. Here we would have categories {biolink:GenomicEntity, biolink:MolecularEntity, biolink:NamedThing}
     * Range: [CategoryType](types/CategoryType.md)
     * in subsets: (translator_minimal)
 * [type](type.md)  <sub>0..1</sub>
     * Range: [String](types/String.md)
 * [name](name.md)  <sub>0..1</sub>
     * Description: A human-readable name for an attribute or entity.
     * Range: [LabelType](types/LabelType.md)
     * in subsets: (translator_minimal,samples)
 * [description](description.md)  <sub>0..1</sub>
     * Description: a human-readable description of an entity
     * Range: [NarrativeText](types/NarrativeText.md)
     * in subsets: (translator_minimal)
 * [source](source.md)  <sub>0..1</sub>
     * Description: a lightweight analog to the association class 'has provider' slot, which is the string name, or the authoritative (i.e. database) namespace, designating the origin of the entity to which the slot belongs.
     * Range: [LabelType](types/LabelType.md)
     * in subsets: (translator_minimal)
 * [provided by](provided_by.md)  <sub>0..\*</sub>
     * Description: connects an association to the agent (person, organization or group) that provided it
     * Range: [Agent](Agent.md)
 * [has attribute](has_attribute.md)  <sub>0..\*</sub>
     * Description: connects any entity to an attribute
     * Range: [Attribute](Attribute.md)
     * in subsets: (samples)
